Exception: Silas::CheckpointInLedgerError

Inherits:
Error
  • Object
show all
Defined in:
lib/silas/errors.rb

Overview

A continuation checkpoint occurred inside a ledger transaction. Checkpoints raise Interrupt, which would roll back the ledger row + side effects while the continuation believes progress was made (spike finding #5).